@@ -4,10 +4,11 @@
 ##' 
 {
 
-  if (require (svUnit, quietly = TRUE)){
+  if (require ("svUnit", quietly = TRUE)){
     `.test<-` <- svUnit::`test<-`
   } else {
     `.test<-` <- function (f, value) {
+      class (value) <-  c ("svTest", "function")
       attr (f, "test") <- value
       f
     }
